@@ -14,6 +14,6 @@ def test_get_project_by_name():
 def test_get_project_by_id():
     """Test get_project_by_id method."""
     c = Client(tier=os.getenv("BLN_TEST_ENV", "dev"))
-    id = "UHJvamVjdDpiZGM5NmU1MS1kMzBhLTRlYTctODY4Yi04ZGI4N2RjMzQ1ODI="
-    p = c.get_project_by_id(id)
-    assert p["id"] == id
+    id_ = "UHJvamVjdDpiZGM5NmU1MS1kMzBhLTRlYTctODY4Yi04ZGI4N2RjMzQ1ODI="
+    p = c.get_project_by_id(id_)
+    assert p["id"] == id_
